==> RIP-0.3.1beta1.tar.gz: RIP-0.3.1beta1/modules/ud/ud_comrol.h <==
/***************************************
  $Revision: 1.8 $

  Status: NOT REVUED, NOT TESTED

 Author(s):       Andrei Robachevsky

  ******************/ /******************
  Modification History:
        andrei (17/01/2000) Created.
  ******************/ /******************
  Copyright (c) 2000                              RIPE NCC
 
  All Rights Reserved
  
  Permission to use, copy, modify, and distribute this software and its
  documentation for any purpose and without fee is hereby granted,
  provided that the above copyright notice appear in all copies and that
  both that copyright notice and this permission notice appear in
  supporting documentation, and that the name of the author not be
  used in advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.
  
  THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
  AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 ***************************************/

#define TAB_START	6
char *t_ab[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "admin_c","tech_c","notify","mnt_by","mnt_lower",NULL };
                
char *t_an[]={	"mntner","person_role","as_set","names","mbrs_by_ref",NULL,
		"cross_nfy","cross_mnt","member_of","admin_c","tech_c","notify","mnt_by","mnt_lower","mnt_routes",NULL };
		
char *t_dn[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","tech_c","zone_c","nserver","sub_dom","notify","mnt_by","mnt_lower","refer","inaddr_arpa", NULL }; /*C_DN, */
		
char *t_i6[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","tech_c","rev_srv","notify","mnt_by","mnt_lower","mnt_routes",NULL}; /*C_I6,*/

char *t_in[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","tech_c","rev_srv","notify","mnt_by","mnt_lower","mnt_routes",NULL}; /*C_IN,*/
		
char *t_ir[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"ifaddr","admin_c","tech_c","notify","mnt_by",NULL}; /*C_IR,*/
		
char *t_kc[]={	"mntner",NULL,NULL,NULL,NULL,NULL,
		"notify","mnt_by",NULL}; /*C_KC,*/
		
char *t_li[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","author","notify","mnt_by",NULL}; /*C_LI,*/
		
char *t_mt[]={	"person_role","names",NULL,NULL,NULL,NULL,
		"admin_c","tech_c","upd_to","mnt_nfy","auth","notify","mnt_by","auth_override",NULL}; /*C_MT,*/
		
char *t_pn[]={	"mntner",NULL,NULL,NULL,NULL,NULL,
		"names","e_mail","notify","mnt_by",NULL}; /*C_PN,*/
		
char *t_ro[]={	"mntner",NULL,NULL,NULL,NULL,NULL,
		"names","e_mail","admin_c","tech_c","notify","mnt_by",NULL}; /**C_RO,*/
		
char *t_rt[]={	"route_set","mntner","person_role",NULL,NULL,NULL, /* admin-c, tech-c may appear in RADB */
		"cross_nfy","cross_mnt","member_of","notify","mnt_by","mnt_lower", "mnt_routes", NULL}; /*C_RT,*/
		
char *t_as[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"mbrs_by_ref","admin_c","tech_c","notify","mnt_by",NULL}; /*C_AS,*/
		
char *t_rs[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"mbrs_by_ref","admin_c","tech_c","notify","mnt_by",NULL}; /*C_RS,*/
		
char *t_fs[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "admin_c","tech_c","notify","mnt_by",NULL,NULL}; /*C_FS,*/
                
char *t_ps[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "admin_c","tech_c","notify","mnt_by",NULL,NULL}; /*C_PS,*/
                
char *t_is[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "mbrs_by_ref","admin_c","tech_c","notify","mnt_by",NULL}; /*C_IS,*/
                

/* IMPORTANT !!! */
/* This stuff should be consistent with DF_classnames.def */

char **tables[]={
t_ab,
t_as,
t_an,
t_dn,
t_ir,
t_i6,
t_in,
t_kc,
t_li,
t_mt,
t_pn,
t_ro,
t_rt,
t_rs,
t_fs,
t_ps,
t_is,
NULL
};

/* This tables are used for inverse querying when deleting an object */

char *t_ipn[]={  "admin_c","tech_c","zone_c","cross_nfy","author",NULL}; /*C_PN, C_RO*/
char *t_imt[]={  "mnt_by","mnt_lower","mnt_routes","cross_mnt","mbrs_by_ref",NULL}; /* C_MT */

==> RIP-0.4.2beta1.tar.gz: RIP-0.4.2beta1/modules/ud/ud_comrol.h <==
/***************************************
  $Revision: 1.9 $

  Status: NOT REVUED, NOT TESTED

 Author(s):       Andrei Robachevsky

  ******************/ /******************
  Modification History:
        andrei (17/01/2000) Created.
  ******************/ /******************
  Copyright (c) 2000                              RIPE NCC
 
  All Rights Reserved
  
  Permission to use, copy, modify, and distribute this software and its
  documentation for any purpose and without fee is hereby granted,
  provided that the above copyright notice appear in all copies and that
  both that copyright notice and this permission notice appear in
  supporting documentation, and that the name of the author not be
  used in advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.
  
  THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
  AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 ***************************************/

#define TAB_START	6
char *t_ab[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "admin_c","tech_c","notify","mnt_by","mnt_lower",NULL };
                
char *t_an[]={	"mntner","person_role","as_set","names","mbrs_by_ref",NULL,
		"cross_nfy","cross_mnt","member_of","admin_c","tech_c","notify","mnt_by","mnt_lower","mnt_routes",NULL };
		
char *t_dn[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","tech_c","zone_c","nserver","sub_dom","notify","mnt_by","mnt_lower","refer","inaddr_arpa", NULL }; /*C_DN, */
		
char *t_i6[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","tech_c","rev_srv","notify","mnt_by","mnt_lower","mnt_routes",NULL}; /*C_I6,*/

char *t_in[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","tech_c","rev_srv","notify","mnt_by","mnt_lower","mnt_routes",NULL}; /*C_IN,*/
		
char *t_ir[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"ifaddr","admin_c","tech_c","notify","mnt_by",NULL}; /*C_IR,*/
		
char *t_kc[]={	"mntner",NULL,NULL,NULL,NULL,NULL,
		"notify","mnt_by",NULL}; /*C_KC,*/
		
char *t_li[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"admin_c","author","notify","mnt_by",NULL}; /*C_LI,*/
		
char *t_mt[]={	"person_role","names",NULL,NULL,NULL,NULL,
		"admin_c","tech_c","upd_to","mnt_nfy","auth","notify","mnt_by","auth_override","referral_by",NULL}; /*C_MT,*/
		
char *t_pn[]={	"mntner",NULL,NULL,NULL,NULL,NULL,
		"names","e_mail","notify","mnt_by",NULL}; /*C_PN,*/
		
char *t_ro[]={	"mntner",NULL,NULL,NULL,NULL,NULL,
		"names","e_mail","admin_c","tech_c","notify","mnt_by",NULL}; /**C_RO,*/
		
char *t_rt[]={	"route_set","mntner","person_role",NULL,NULL,NULL, /* admin-c, tech-c may appear in RADB */
		"cross_nfy","cross_mnt","member_of","notify","mnt_by","mnt_lower", "mnt_routes", NULL}; /*C_RT,*/
		
char *t_as[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"mbrs_by_ref","admin_c","tech_c","notify","mnt_by",NULL}; /*C_AS,*/
		
char *t_rs[]={	"mntner","person_role","names",NULL,NULL,NULL,
		"mbrs_by_ref","admin_c","tech_c","notify","mnt_by",NULL}; /*C_RS,*/
		
char *t_fs[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "admin_c","tech_c","notify","mnt_by",NULL,NULL}; /*C_FS,*/
                
char *t_ps[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "admin_c","tech_c","notify","mnt_by",NULL,NULL}; /*C_PS,*/
                
char *t_is[]={  "mntner","person_role","names",NULL,NULL,NULL,
                "mbrs_by_ref","admin_c","tech_c","notify","mnt_by",NULL}; /*C_IS,*/
                

/* IMPORTANT !!! */
/* This stuff should be consistent with DF_classnames.def */

char **tables[]={
t_ab,
t_as,
t_an,
t_dn,
t_ir,
t_i6,
t_in,
t_kc,
t_li,
t_mt,
t_pn,
t_ro,
t_rt,
t_rs,
t_fs,
t_ps,
t_is,
NULL
};

/* This tables are used for inverse querying when deleting an object */

char *t_ipn[]={  "admin_c","tech_c","zone_c","cross_nfy","author",NULL}; /*C_PN, C_RO*/
char *t_imt[]={  "mnt_by","mnt_lower","mnt_routes","cross_mnt","mbrs_by_ref","referral_by",NULL}; /* C_MT */
